@@ -20,10 +20,8 @@
 */
 
 #include "config.h"
-
-#include <epan/expert.h>
 #include <epan/packet.h>
-
+#include <epan/expert.h>
 #include <file-rbm.h>
 #include <wiretap/ruby_marshal.h>
 
@@ -193,7 +191,6 @@ static void dissect_rbm_string_data(tvbuff_t* tvb, packet_info* pinfo, proto_tre
 	dissect_rbm_string_data_trailer(tvb, pinfo, tree, offset, label, prefix, "", value_str);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_array(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value;
@@ -220,7 +217,6 @@ static void dissect_rbm_array(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tre
 		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_hash(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint32 value;
@@ -314,13 +310,12 @@ static void dissect_rbm_struct_data(tvbuff_t* tvb, packet_info* pinfo, proto_tre
 
 	rbm_set_info(pinfo, "Struct");
 	get_rbm_integer(tvb, *offset, &value, &len);
-	proto_tree_add_item(tree, hf_rbm_struct, tvb, *offset + 1, value, ENC_ASCII|ENC_NA);
+	proto_tree_add_item(tree, hf_rbm_struct, tvb, *offset + 1, value, ENC_ASCII);
 	*offset += 1 + value;
 	if (value_str)
 		*value_str = wmem_strdup_printf(pinfo->pool, "%d", value);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_string(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "String", "", value);
@@ -329,7 +324,6 @@ static void dissect_rbm_string(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tr
 	dissect_rbm_object(tvb, pinfo, tree, offset, NULL, NULL);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_regex(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_string_data_trailer(tvb, pinfo, tree, offset, "Regexp", "/", "/", value);
@@ -345,7 +339,6 @@ static void dissect_rbm_class(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tre
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Class", "", value_str);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_userclass(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	rbm_set_info(pinfo, "UserClass");
@@ -357,7 +350,6 @@ static void dissect_rbm_symbol(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tr
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Symbol", ":", value_str);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_variable(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value_str)
 {
 	gint offset_start = *offset;
@@ -371,14 +363,12 @@ static void dissect_rbm_module(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tr
 	dissect_rbm_string_data(tvb, pinfo, tree, offset, "Module", "", value_str);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_struct(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** value)
 {
 	dissect_rbm_struct_data(tvb, pinfo, tree, offset, value);
 	dissect_rbm_hash(tvb, pinfo, tree, offset, NULL);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_drb(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
@@ -388,7 +378,6 @@ static void dissect_rbm_drb(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
 	proto_item_set_len(drb_tree, *offset - offset_start);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_rubyobject(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
@@ -406,7 +395,6 @@ static void dissect_rbm_rubyobject(tvbuff_t* tvb, packet_info* pinfo, proto_tree
 	proto_item_set_len(obj_tree, *offset - offset_start);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_extended(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
 {
 	gint offset_start = *offset;
@@ -417,7 +405,6 @@ static void dissect_rbm_extended(tvbuff_t* tvb, packet_info* pinfo, proto_tree*
 	proto_item_set_len(ext_tree, *offset - offset_start);
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* ptree, guint* offset, gchar** type, gchar** value)
 {
 	guint8 subtype = tvb_get_guint8(tvb, *offset);
@@ -431,8 +418,6 @@ static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* pt
 	proto_tree_add_item(tree, hf_rbm_type, tvb, *offset, 1, ENC_NA);
 	*offset += 1;
 
-	increment_dissection_depth(pinfo);
-
 	switch (subtype) {
 		case '0':
 		case 'T':
@@ -522,8 +507,6 @@ static void dissect_rbm_object(tvbuff_t* tvb, packet_info* pinfo, proto_tree* pt
 		*type = type_local;
 	if (value)
 		*value = value_local;
-
-	decrement_dissection_depth(pinfo);
 }
 
 static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset)
@@ -547,7 +530,6 @@ static gboolean dissect_rbm_header(tvbuff_t* tvb, packet_info* pinfo, proto_tree
 	return TRUE;
 }
 
-// NOLINTNEXTLINE(misc-no-recursion)
 void dissect_rbm_inline(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, guint* offset, gchar** type, gchar** value)
 {
 	if (!dissect_rbm_header(tvb, pinfo, tree, offset))
