@@ -524,11 +524,11 @@ dissect_fcfzs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data)
 
     if ((opcode != FCCT_MSG_ACC) && (opcode != FCCT_MSG_RJT)) {
         conversation = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst,
-                                         conversation_pt_to_endpoint_type(pinfo->ptype), fchdr->oxid,
+                                         conversation_pt_to_conversation_type(pinfo->ptype), fchdr->oxid,
                                          fchdr->rxid, NO_PORT_B);
         if (!conversation) {
             conversation = conversation_new(pinfo->num, &pinfo->src, &pinfo->dst,
-                                            conversation_pt_to_endpoint_type(pinfo->ptype), fchdr->oxid,
+                                            conversation_pt_to_conversation_type(pinfo->ptype), fchdr->oxid,
                                             fchdr->rxid, NO_PORT2);
         }
 
@@ -559,7 +559,7 @@ dissect_fcfzs(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data)
     else {
         /* Opcode is ACC or RJT */
         conversation = find_conversation(pinfo->num, &pinfo->src, &pinfo->dst,
-                                         conversation_pt_to_endpoint_type(pinfo->ptype), fchdr->oxid,
+                                         conversation_pt_to_conversation_type(pinfo->ptype), fchdr->oxid,
                                          fchdr->rxid, NO_PORT_B);
         isreq = FALSE;
         if (!conversation) {
