@@ -194,7 +194,7 @@ static void dissect_getnamebyaddr_request(tvbuff_t* tvb, proto_tree* lwres_tree)
     flags = tvb_get_ntohl(tvb, LWRES_LWPACKET_LENGTH);
     family = tvb_get_ntohl(tvb, LWRES_LWPACKET_LENGTH + 4);
     addrlen = tvb_get_ntohs(tvb, LWRES_LWPACKET_LENGTH + 8);
-    addrs = tvb_ip_to_str(tvb, LWRES_LWPACKET_LENGTH + 10);
+    addrs = tvb_ip_to_str(wmem_packet_scope(), tvb, LWRES_LWPACKET_LENGTH + 10);
     slen = (int)strlen(addrs);
 
     if (lwres_tree == NULL)
@@ -259,7 +259,7 @@ static void dissect_getnamebyaddr_response(tvbuff_t* tvb, packet_info *pinfo, pr
                         tvb,
                         LWRES_LWPACKET_LENGTH + 8,
                         realnamelen,
-                        ENC_ASCII|ENC_NA);
+                        ENC_ASCII);
 
     offset=LWRES_LWPACKET_LENGTH + 8 + realnamelen;
 
@@ -285,7 +285,7 @@ static void dissect_getnamebyaddr_response(tvbuff_t* tvb, packet_info *pinfo, pr
                                 tvb,
                                 offset + 2,
                                 aliaslen,
-                                ENC_ASCII|ENC_NA);
+                                ENC_ASCII);
 
             offset+=(2 + aliaslen + 1);
         }
@@ -334,7 +334,7 @@ static void dissect_getaddrsbyname_request(tvbuff_t* tvb, proto_tree* lwres_tree
                 tvb,
                 LWRES_LWPACKET_LENGTH+10,
                 namelen,
-                ENC_ASCII|ENC_NA);
+                ENC_ASCII);
 
 }
 
@@ -377,7 +377,7 @@ static void dissect_getaddrsbyname_response(tvbuff_t* tvb, packet_info *pinfo, p
                 LWRES_LWPACKET_LENGTH + 8, 2, ENC_BIG_ENDIAN);
 
     proto_tree_add_item(adn_resp_tree, hf_adn_realname, tvb,
-                LWRES_LWPACKET_LENGTH + 10, realnamelen, ENC_ASCII|ENC_NA);
+                LWRES_LWPACKET_LENGTH + 10, realnamelen, ENC_ASCII);
 
     offset = LWRES_LWPACKET_LENGTH + 10 + realnamelen + 1;
 
@@ -395,7 +395,7 @@ static void dissect_getaddrsbyname_response(tvbuff_t* tvb, packet_info *pinfo, p
                         offset, 2, aliaslen);
 
             proto_tree_add_item(alias_tree, hf_adn_aliasname, tvb,
-                        offset + 2, aliaslen, ENC_ASCII|ENC_NA);
+                        offset + 2, aliaslen, ENC_ASCII);
 
             offset+=(2 + aliaslen + 1);
         }
@@ -407,7 +407,7 @@ static void dissect_getaddrsbyname_response(tvbuff_t* tvb, packet_info *pinfo, p
         {
             family = tvb_get_ntohl(tvb, offset);
             length = tvb_get_ntohs(tvb, offset + 4);
-            addrs = tvb_ip_to_str(tvb, offset + 6);
+            addrs = tvb_ip_to_str(pinfo->pool, tvb, offset + 6);
             slen = (int)strlen(addrs);
 
             addr_tree = proto_tree_add_subtree_format(adn_resp_tree,tvb, offset, 4+2+4, ett_adn_addr, NULL, "Address %s", addrs);
@@ -447,7 +447,7 @@ static void dissect_a_records(tvbuff_t* tvb, proto_tree* tree,guint32 nrec,int o
 
         curr = offset + (int)((sizeof(guint32)+sizeof(guint16)) * i);
 
-        addrs = tvb_ip_to_str(tvb, curr+2);
+        addrs = tvb_ip_to_str(wmem_packet_scope(), tvb, curr+2);
 
         addr_tree = proto_tree_add_subtree_format(a_rec_tree, tvb, curr,
                             6, ett_a_rec_addr, NULL, "Address %s", addrs);
@@ -665,7 +665,7 @@ static void dissect_rdata_request(tvbuff_t* tvb, proto_tree* lwres_tree)
             tvb,
             LWRES_LWPACKET_LENGTH+10,
             namelen,
-                ENC_ASCII|ENC_NA);
+                ENC_ASCII);
 
 }
 
@@ -741,7 +741,7 @@ static void dissect_rdata_response(tvbuff_t* tvb, packet_info *pinfo, proto_tree
                         tvb,
                         LWRES_LWPACKET_LENGTH+18,
                         realnamelen,
-                ENC_ASCII|ENC_NA);
+                ENC_ASCII);
 
     switch(rdtype)
     {
@@ -1043,11 +1043,11 @@ proto_register_lwres(void)
             "lwres srv weight", HFILL }},
 
         { &hf_srv_port,
-          { "Port" , "lwres.srv.port", FT_UINT16, BASE_DEC, NULL, 0x0,
+          { "Port", "lwres.srv.port", FT_UINT16, BASE_DEC, NULL, 0x0,
             "lwres srv port", HFILL }},
 
         { &hf_srv_dname,
-          { "DNAME" , "lwres.srv.dname", FT_STRING, BASE_NONE, NULL, 0x0,
+          { "DNAME", "lwres.srv.dname", FT_STRING, BASE_NONE, NULL, 0x0,
             NULL, HFILL }},
 
         { &hf_adn_flags,
@@ -1095,7 +1095,7 @@ proto_register_lwres(void)
             "lwres adn addr addr", HFILL }},
 
         { &hf_ns_dname,
-          { "Name" , "lwres.ns.dname", FT_STRING, BASE_NONE, NULL, 0x0,
+          { "Name", "lwres.ns.dname", FT_STRING, BASE_NONE, NULL, 0x0,
             NULL, HFILL }},
 
         /* Add more fields here */
